@@ -35,7 +35,7 @@ module Bunny
 
     def initialize(session, host, port, opts)
       @session        = session
-      @session_thread = opts[:session_thread]
+      @session_error_handler = opts[:session_error_handler]
       @host    = host
       @port    = port
       @opts    = opts
@@ -146,7 +146,7 @@ module Bunny
           if @session.automatically_recover?
             @session.handle_network_failure(e)
           else
-            @session_thread.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
+            @session_error_handler.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
           end
         end
       end
@@ -170,7 +170,7 @@ module Bunny
           if @session.automatically_recover?
             @session.handle_network_failure(e)
           else
-            @session_thread.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
+            @session_error_handler.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
           end
         end
       end
@@ -188,7 +188,7 @@ module Bunny
         if @session.automatically_recover?
           @session.handle_network_failure(e)
         else
-          @session_thread.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
+          @session_error_handler.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
         end
       end
     end
@@ -245,7 +245,7 @@ module Bunny
         if @session.automatically_recover?
           raise
         else
-          @session_thread.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
+          @session_error_handler.raise(Bunny::NetworkFailure.new("detected a network failure: #{e.message}", e))
         end
       end
     end
@@ -453,9 +453,9 @@ module Bunny
       end
     end
 
-    def initialize_tls_context(ctx, opts={})
+    def initialize_tls_context(ctx, opts = {})
       ctx.cert       = OpenSSL::X509::Certificate.new(@tls_certificate) if @tls_certificate
-      ctx.key        = OpenSSL::PKey::RSA.new(@tls_key) if @tls_key
+      ctx.key        = OpenSSL::PKey.read(@tls_key) if @tls_key
       ctx.cert_store = if @tls_certificate_store
                          @tls_certificate_store
                        else
@@ -463,8 +463,9 @@ module Bunny
                          @tls_ca_certificates = tls_ca_certificates_paths_from(opts)
                          initialize_tls_certificate_store(@tls_ca_certificates)
                        end
+      should_silence_warnings = opts.fetch(:tls_silence_warnings, false)
 
-      if !@tls_certificate
+      if !@tls_certificate && !should_silence_warnings
         @logger.warn <<-MSG
 Using TLS but no client certificate is provided. If RabbitMQ is configured to require & verify peer
 certificate, connection will be rejected. Learn more at https://www.rabbitmq.com/ssl.html
@@ -482,14 +483,14 @@ certificate, connection will be rejected. Learn more at https://www.rabbitmq.com
       @logger.debug { "Will use peer verification mode #{verify_mode}" }
       ctx.verify_mode = verify_mode
 
-      if !@verify_peer
+      if !@verify_peer && !should_silence_warnings
         @logger.warn <<-MSG
 Using TLS but peer hostname verification is disabled. This is convenient for local development
 but prone to man-in-the-middle attacks. Please set verify_peer: true in production. Learn more at https://www.rabbitmq.com/ssl.html
         MSG
       end
 
-      ssl_version = opts[:tls_protocol] || opts[:ssl_version]
+      ssl_version = opts[:tls_protocol] || opts[:ssl_version] || :TLSv1_2
       ctx.ssl_version = ssl_version if ssl_version
 
       ctx
@@ -501,7 +502,7 @@ but prone to man-in-the-middle attacks. Please set verify_peer: true in producti
       certs.each do |cert|
         # if it starts with / or C:/ then it's a file path that may or may not
         # exist (e.g. a default OpenSSL path). MK.
-        if File.readable?(cert) || cert =~ /^([a-z]:?)?\//i
+        if File.readable?(cert) || cert =~ /\A([a-z]:?)?\//i
           cert_files.push(cert)
         else
           cert_inlines.push(cert)
