@@ -2,7 +2,7 @@ require "spec_helper"
 
 describe Bunny::Channel, "#reject" do
   let(:connection) do
-    c = Bunny.new(:user => "bunny_gem", :password => "bunny_password", :vhost => "bunny_testbed")
+    c = Bunny.new(username: "bunny_gem", password: "bunny_password", vhost: "bunny_testbed")
     c.start
     c
   end
@@ -14,13 +14,13 @@ describe Bunny::Channel, "#reject" do
   context "with requeue = true" do
     it "requeues a message" do
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.manual-acks", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.manual-acks", exclusive: true)
       x  = ch.default_exchange
 
-      x.publish("bunneth", :routing_key => q.name)
+      x.publish("bunneth", routing_key: q.name)
       sleep(0.5)
       expect(q.message_count).to eq 1
-      delivery_info, _, _ = q.pop(:manual_ack => true)
+      delivery_info, _, _ = q.pop(manual_ack: true)
 
       ch.reject(delivery_info.delivery_tag, true)
       sleep(0.5)
@@ -33,20 +33,20 @@ describe Bunny::Channel, "#reject" do
   context "with requeue = false" do
     it "rejects a message" do
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.with-requeue-false", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.with-requeue-false", exclusive: true)
       x  = ch.default_exchange
 
-      x.publish("bunneth", :routing_key => q.name)
+      x.publish("bunneth", routing_key: q.name)
       sleep(0.5)
       expect(q.message_count).to eq 1
-      delivery_info, _, _ = q.pop(:manual_ack => true)
+      delivery_info, _, _ = q.pop(manual_ack: true)
 
       ch.reject(delivery_info.delivery_tag, false)
       sleep(0.5)
       ch.close
 
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.with-requeue-false", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.with-requeue-false", exclusive: true)
       expect(q.message_count).to eq 0
       ch.close
     end
@@ -56,13 +56,13 @@ describe Bunny::Channel, "#reject" do
   context "with an invalid (random) delivery tag" do
     it "causes a channel-level error" do
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.unknown-delivery-tag", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.unknown-delivery-tag", exclusive: true)
       x  = ch.default_exchange
 
-      x.publish("bunneth", :routing_key => q.name)
+      x.publish("bunneth", routing_key: q.name)
       sleep(0.25)
       expect(q.message_count).to eq 1
-      _, _, content = q.pop(:manual_ack => true)
+      _, _, content = q.pop(manual_ack: true)
 
       ch.on_error do |ch, channel_close|
         @channel_close = channel_close
@@ -78,7 +78,7 @@ end
 
 describe Bunny::Channel, "#basic_reject" do
   let(:connection) do
-    c = Bunny.new(:user => "bunny_gem", :password => "bunny_password", :vhost => "bunny_testbed")
+    c = Bunny.new(username: "bunny_gem", password: "bunny_password", vhost: "bunny_testbed")
     c.start
     c
   end
@@ -90,13 +90,13 @@ describe Bunny::Channel, "#basic_reject" do
   context "with requeue = true" do
     it "requeues a message" do
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.manual-acks", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.manual-acks", exclusive: true)
       x  = ch.default_exchange
 
-      x.publish("bunneth", :routing_key => q.name)
+      x.publish("bunneth", routing_key: q.name)
       sleep(0.5)
       expect(q.message_count).to eq 1
-      delivery_info, _, _ = q.pop(:manual_ack => true)
+      delivery_info, _, _ = q.pop(manual_ack: true)
 
       ch.basic_reject(delivery_info.delivery_tag.to_i, true)
       sleep(0.5)
@@ -109,20 +109,20 @@ describe Bunny::Channel, "#basic_reject" do
   context "with requeue = false" do
     it "rejects a message" do
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.with-requeue-false", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.with-requeue-false", exclusive: true)
       x  = ch.default_exchange
 
-      x.publish("bunneth", :routing_key => q.name)
+      x.publish("bunneth", routing_key: q.name)
       sleep(0.5)
       expect(q.message_count).to eq 1
-      delivery_info, _, _ = q.pop(:manual_ack => true)
+      delivery_info, _, _ = q.pop(manual_ack: true)
 
       ch.basic_reject(delivery_info.delivery_tag.to_i, false)
       sleep(0.5)
       ch.close
 
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.with-requeue-false", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.with-requeue-false", exclusive: true)
       expect(q.message_count).to eq 0
       ch.close
     end
@@ -131,20 +131,20 @@ describe Bunny::Channel, "#basic_reject" do
   context "with requeue = default" do
     it "rejects a message" do
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.with-requeue-false", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.with-requeue-false", exclusive: true)
       x  = ch.default_exchange
 
-      x.publish("bunneth", :routing_key => q.name)
+      x.publish("bunneth", routing_key: q.name)
       sleep(0.5)
       expect(q.message_count).to eq 1
-      delivery_info, _, _ = q.pop(:manual_ack => true)
+      delivery_info, _, _ = q.pop(manual_ack: true)
 
       ch.basic_reject(delivery_info.delivery_tag.to_i)
       sleep(0.5)
       ch.close
 
       ch = connection.create_channel
-      q  = ch.queue("bunny.basic.reject.with-requeue-false", :exclusive => true)
+      q  = ch.queue("bunny.basic.reject.with-requeue-false", exclusive: true)
       expect(q.message_count).to eq 0
       ch.close
     end
