@@ -2,7 +2,7 @@ require "spec_helper"
 
 describe Bunny::Queue, "#subscribe" do
   let(:connection) do
-    c = Bunny.new(:user => "bunny_gem", :password => "bunny_password", :vhost => "bunny_testbed")
+    c = Bunny.new(username: "bunny_gem", password: "bunny_password", vhost: "bunny_testbed")
     c.start
     c
   end
@@ -20,8 +20,8 @@ describe Bunny::Queue, "#subscribe" do
 
     t = Thread.new do
       ch = connection.create_channel
-      q = ch.queue(queue_name, :auto_delete => true, :durable => false)
-      q.subscribe(:exclusive => true, :manual_ack => false) do |delivery_info, properties, payload|
+      q = ch.queue(queue_name, auto_delete: true, durable: false)
+      q.subscribe(exclusive: true, manual_ack: false) do |delivery_info, properties, payload|
         metadata = properties
         envelope = delivery_info
       end
@@ -32,28 +32,28 @@ describe Bunny::Queue, "#subscribe" do
     ch = connection.create_channel
     x  = ch.default_exchange
     x.publish("hello",
-              :routing_key => queue_name,
-              :app_id      => "bunny.example",
-              :priority    => 8,
-              :type        => "kinda.checkin",
+              routing_key: queue_name,
+              app_id: "bunny.example",
+              priority: 8,
+              type: "kinda.checkin",
               # headers table keys can be anything
-              :headers     => {
-                :coordinates => {
-                  :latitude  => 59.35,
-                  :longitude => 18.066667
+              headers: {
+                coordinates: {
+                  latitude: 59.35,
+                  longitude: 18.066667
                 },
-                :time         => @now,
-                :participants => 11,
-                :venue        => "Stockholm",
-                :true_field   => true,
-                :false_field  => false,
-                :nil_field    => nil,
-                :ary_field    => ["one", 2.0, 3, [{"abc" => 123}]]
+                time: @now,
+                participants: 11,
+                venue: "Stockholm",
+                true_field: true,
+                false_field: false,
+                nil_field: nil,
+                ary_field: ["one", 2.0, 3, [{"abc" => 123}]]
               },
-              :timestamp      => @now.to_i,
-              :reply_to       => "a.sender",
-              :correlation_id => "r-1",
-              :message_id     => "m-1")
+              timestamp: @now.to_i,
+              reply_to: "a.sender",
+              correlation_id: "r-1",
+              message_id: "m-1")
 
     sleep 0.7
 
