@@ -4,7 +4,7 @@ describe Bunny::Session do
   context "with unreachable host" do
     it "raises Bunny::TCPConnectionFailed" do
       begin
-        conn = Bunny.new(:hostname => "192.192.192.192")
+        conn = Bunny.new(:hostname => "127.0.0.254", :port => 1433)
         conn.start
 
         fail "expected 192.192.192.192 to be unreachable"
